package server

import (
	agent "0xacab.org/leap/menshen-agent"
	"0xacab.org/leap/menshen/models"
	"0xacab.org/leap/obfsvpn/obfsvpn"
)

const transportName = "obfs4"

// Obfs4Config is an obfs4 specific configuration object
type Obfs4Config struct {
	NodeID     string `json:"node-id"`
	PrivateKey string `json:"private-key"`
	PublicKey  string `json:"public-key"`
	DRBGSeed   string `json:"drbg-seed"`
	IatMode    int    `json:"iat-mode"`
}

// MenshenAgentConfig is for configuring menshen-agent behaviour
type MenshenAgentConfig struct {
	Enabled bool

	agent.Config[models.ModelsBridge]
}

// Config is the configuration for the obfsvpn server
type Config struct {
	OpenvpnAddr        string
	Obfs4Config        Obfs4Config
	StateDir           string
	Obfs4ListenIP      string
	Obfs4ListenPort    int
	HoppingEnabled     bool
	PortSeed           int64
	PortCount          uint
	MinHopPort         uint
	MaxHopPort         uint
	KCPConfig          obfsvpn.KCPConfig
	QUICConfig         obfsvpn.QUICConfig
	MenshenAgentConfig MenshenAgentConfig
}
